@@ -3,7 +3,6 @@ from .remote_control.instrument import instrument
 from .remote_control.instrumentRS import instrumentRS
 from .remote_control.instrumentRS_FSW import instrumentRS_FSW
 from .remote_control.instrumentRSExceptions import InstrumentError
-#from .remote_control.AmplifierMeasurement import AmplifierMeasurement
 
 from .iq_data_handling.iqdata import Iqiq2Complex
 from .iq_data_handling.iqdata import Iiqq2Complex
@@ -18,9 +17,13 @@ from .iq_data_handling.iqdata import ReadIqTar
 from .iq_data_handling.iqdata import Iqw2Iqtar
 from .iq_data_handling.iqdata import Iqw2Wv
 
+from .snp_handling.snpfiles import WriteSnP
+from .snp_handling.snpfiles import ReadSnP
+
 from .signal_generation.signal_generation import CreateWGNSignal
 from .signal_generation.signal_generation import LowPassFilter
 
 from .helper.helper import ShowLogFFT
 from .helper.helper import MeanPower
-from .helper.helper import MaxPower
\ No newline at end of file
+from .helper.helper import MaxPower
+from .helper.helper import ConvertUnit
\ No newline at end of file
