@@ -248,7 +248,7 @@ def ReadWv( FileName, ReadData = True):
 
 
 
-def __WriteXml( fs, NumberOfSamples, filenameiqw, filenamexml):
+def __WriteXml( fs, NumberOfSamples, filenameiqw, filenamexml, fCenterFrequency = 0):
     """Function to write the xml part of the iq.tar
     __WriteXml( samplingrate, numberofsamples, filenameiqw, filenamexml)"""
     
@@ -274,7 +274,9 @@ def __WriteXml( fs, NumberOfSamples, filenameiqw, filenamexml):
     #xmlfile.write("<NumberOfChannels>1</NumberOfChannels>\n")
     xmlfile.write("<DataFilename>" + filenameiqw+ "</DataFilename>\n")
     #Optional
-    #xmlfile.write("<UserData></UserData>\n")
+    if fCenterFrequency != 0:
+        xmlfile.write( f'<UserData><RohdeSchwarz><SpectrumAnalyzer><CenterFrequency unit="Hz">{fCenterFrequency}</CenterFrequency></SpectrumAnalyzer></RohdeSchwarz></UserData>\n')
+    
     xmlfile.write("</RS_IQ_TAR_FileFormat>\n")
     xmlfile.close()
     
@@ -282,7 +284,7 @@ def __WriteXml( fs, NumberOfSamples, filenameiqw, filenamexml):
 
 
 
-def WriteIqTar( iqData, fs, FileName):
+def WriteIqTar( iqData, fs, FileName, fCenterFrequency = 0):
     """Writes an iq.tar file. Complex iqData values are interpreted as Volts.
     iqData can be a list of complex or list of floats (iqiqiq format).
     writtenSamples = WriteIqTar(iqList,fs,"MyFile.iq.tar")"""
@@ -303,7 +305,7 @@ def WriteIqTar( iqData, fs, FileName):
     #xsltfilename = "open_IqTar_xml_file_in_web_browser.xslt"
     
     xmlfilename = re.sub( "iq.tar", "xml", filename, flags=re.IGNORECASE)
-    __WriteXml( fs, NumberOfSamples, binaryfile, os.path.join(path, xmlfilename))
+    __WriteXml( fs, NumberOfSamples, binaryfile, os.path.join(path, xmlfilename), fCenterFrequency=fCenterFrequency)
     
     try:
         tar = tarfile.open( FileName, "w")
@@ -403,11 +405,11 @@ def ReadIqTar( FileName, ChannelToRead = 1):
 
 
 
-def Iqw2Iqtar( FileName, fs, keepIqw = False):
+def Iqw2Iqtar( FileName, fs, keepIqw = False, fCenterFrequency = 0):
     """Converts an iqw file into iq.tar. Suggested to use after directly reading
     binary data from instrument into file (iqw).
     Note: iqw must be in iqiqiq format
-    writtenSamples = WriteIqTar(iqList,fs,"MyFile.iq.tar")"""
+    iqtarFilename = WriteIqTar(iqList,fs,"MyFile.iq.tar")"""
 
     import os
     import tarfile
@@ -427,7 +429,7 @@ def Iqw2Iqtar( FileName, fs, keepIqw = False):
     binaryfile = re.sub( "iqw", "complex.1ch.float32", filename, flags=re.IGNORECASE)
     os.rename( FileName, os.path.join(path, binaryfile))
     
-    __WriteXml( fs, NumberOfSamples, binaryfile, os.path.join(path, xmlfile))
+    __WriteXml( fs, NumberOfSamples, binaryfile, os.path.join(path, xmlfile), fCenterFrequency = fCenterFrequency)
                           
     try:
         tar = tarfile.open( os.path.join(path, iqtarfile), "w")
@@ -444,7 +446,7 @@ def Iqw2Iqtar( FileName, fs, keepIqw = False):
     except:
         logging.error("IqTar (" + FileName +") write error!" )
     
-    return
+    return os.path.join(path, iqtarfile)
 
 
 
