@@ -33,7 +33,7 @@ class instrumentRS(instrument):
         self.Write("MMEM:DATA '" + remoteFile + "',#" + str(instrument.GetNumberOfDigits(statinfo.st_size)) + str(statinfo.st_size), AddTermination = False )
         
         file = open( localFile, "rb")
-        for chunk in iter(partial(file.read, self.__InBufferSize), b''):
+        for chunk in iter(partial(file.read, self._InBufferSize), b''):
             self.Write( chunk, Binary = True, AddTermination = False)
         file.close()
         self.Write("\n")
